#ifndef __TESTMODEL_HXX__
#define __TESTMODEL_HXX__

#ifdef _MSC_VER
#pragma warning (push)
#pragma warning (disable : 4068 ) //Disable warning about unknown pragmas
#endif


// Visibility macros

#include "model-export.hxx"

#include <odb/core.hxx>



// Simple object with just plain datatype columns (works)

#pragma db object table("SimpleObject")
class MODEL_EXPORT SimpleObject {
	friend class odb::access;

public:
	SimpleObject() {}
	virtual ~SimpleObject() {}

	int id() const { return id_; }

private:
#pragma db id column("Key")
	int id_;

#pragma db column("Value") 
	int value_;

};



// Composite Value

#pragma db value
struct MODEL_EXPORT CompositeKey {
private:
	friend class odb::access;

public:
	CompositeKey() : key1_(), key2_()  {}
	CompositeKey(const int &key1, const int &key2) : key1_(key1), key2_(key2) {}
	CompositeKey(const CompositeKey &other) : key1_(other.key1_), key2_(other.key2_) {}
	virtual ~CompositeKey() {}

	bool operator< (const CompositeKey &other) const {
		return key1_ < other.key1_ || (key1_ == other.key1_ && key2_ < other.key2_);
	}

	int key1() const { return key1_; }
	int key2() const { return key2_; }


#pragma db column("Key1") not_null
	int key1_;
#pragma db column("Key2") not_null
	int key2_;
};



// Object with composite value member

#pragma db object table("CompositeObject")
class MODEL_EXPORT CompositeObject {
	friend class odb::access;

public:
	CompositeObject() {}
	virtual ~CompositeObject() {}

	CompositeKey id() const { return id_; }

private:
	//Problematic member. Does not matter if the variable is an id or not
#pragma db id column("")
	CompositeKey id_;

	// UNCOMMENT THIS LINES TO REMOVE LINK ERROR (but still does not work)
	//#pragma db column("Value") 
	//int value_;
};



#ifdef _MSC_VER
#pragma warning (pop) //Restore warnung settings
#endif

#endif //__TESTMODEL_HXX__